from django.core import serializers
from django.http import QueryDict

from .models import CpuData


def add_cpu_util_data(data: QueryDict) -> None:
    """ Добавляет данные об утилизации процессора в соответствующую таблицу."""
    cpu_utilization = data.get("cpu_utilization")
    new_cpu_data = CpuData(cpu_utilization=cpu_utilization)
    new_cpu_data.save()


def get_hundred_last_records():
    """ Получение 100 последних записей из таблицы с данными об утилизации процессора и их сериализация."""
    serialized_last_hundred_records = None
    try:
        serialized_last_hundred_records = serializers.serialize('json', CpuData.objects.all().order_by('-id')[:100],
                                                                fields=["cpu_utilization"])
    except Exception as ex:
        print(ex.args)
    return serialized_last_hundred_records



# Generated by Django 4.2.10 on 2024-05-02 14:48

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CpuData',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('cpu_utilization', models.IntegerField(verbose_name='Утилизация ЦП, %')),
            ],
        ),
    ]



from django.core.handlers.wsgi import WSGIRequest
from django.http import HttpResponse
from django.shortcuts import render
from django.views.decorators.csrf import csrf_exempt

from cpu_checker_service.orm import add_cpu_util_data, get_hundred_last_records


def index(request: WSGIRequest) -> HttpResponse:
    """ Главная страница"""
    cpu_utilization_data = get_hundred_last_records()
    context = {
        'cpu_datas': cpu_utilization_data
    }
    return render(request, r"index.html", context)


@csrf_exempt
def cpu_utilization_data_handler(request: WSGIRequest):
    """ Энд-поинт для получения данных с клиента"""
    if request.method == "POST":
        cpu_util_data = request.POST
        add_cpu_util_data(cpu_util_data)

    return HttpResponse()


def ajax_cpu_endpoint(request):
    """ Энд-поинт возвращающий последние 100 сериализованных записей."""
    cpu_utilization_data = get_hundred_last_records()
    return HttpResponse(cpu_utilization_data, content_type="application/json")



"""Скрипт Setup.py для проекта по упаковке."""
from setuptools import setup

import os


def read_dependencies():
    """Получаем из requirements.txt зависимости по умолчанию."""
    filepath = os.path.join(os.path.dirname(__file__), 'cpu_checker', 'requirements.txt')
    with open(filepath) as requirements_file:
        dependencies = requirements_file.readlines()
        return [dependency for dependency in dependencies]


if __name__ == '__main__':
    setup(
        name='cpu_utilization_monitoring',
        version='0.1.3',
        author='Basov Ivan',
        author_email='demon_cuc@mail.ru',
        url='https://github.com/zeleniyToster/test_task_carbon_soft',
        download_url='https://github.com/zeleniyToster/test_task_carbon_soft/archive/refs/heads/master.zip',
        package_dir={'': 'cpu_checker'},
        package_data={
            '': ['*', 'requirements.txt', '*/requirements.txt'],
        },
        description='Тестовое задание для carbon soft.',
        python_requires='>=3.10.4',
        install_requires=[
              *read_dependencies(),
        ],
    )
